RxPersistStringList class
Rx persistent class for List<String> Type.
Constructors
-
RxPersistStringList(String key, List<
String> initial) -
Rx persistent class, with the persistent key of
_persistKey.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ob
→ List<
String> -
Notify the host to rebuild related consume widget and then return
the underlying object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
rxAspects
→ Set<
Object> -
finalinherited
-
value
↔ List<
String> -
Getter:
getter/setter pairinherited
Methods
-
addRxAspects(
[Object? aspects]) → void -
Add
aspectsto the Rx aspects. param aspects: Iterable: addaspectsto the rx aspects null: broadcast to the model RxImpl: add(aspects as RxImpl).rxAspectsto the rx aspects : addaspectsto the rx aspectsinherited -
clearRxAspects(
) → void -
Clear all the Rx aspects.
inherited
-
consume(
Widget create(), {Key? key}) → Widget -
Create a consume widget and connect with the watched variable.
The consume widget will rebuild whenever the watched variable updates.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
) → void -
Synonym of
publishRxAspects().inherited -
publishRxAspects(
) → void -
Publish Rx aspects to the host.
inherited
-
remove(
) → void -
Override, to enclosure
super.removeinscheduleMicrotaskto make sureremovewon't precedeob.updateMethod.override -
removeRxAspects(
[Object? aspects]) → void -
Remove
aspectsfrom the Rx aspects. param aspects: Iterable: removeaspectsfrom the rx aspects null: don't broadcast to the model RxImpl: remove(aspects as RxImpl).rxAspectsfrom the rx aspects : removeaspectsfrom the rx aspectsinherited -
retainRxAspects(
Object aspects) → void -
Retain
aspectsin the Rx aspects. param aspects: Iterable: retain rx aspects in theaspectsRxImpl: retain rx aspects in the(aspects as RxImpl).rxAspects: retain rx aspects in theaspectsinherited -
store(
List< String> input) → void -
Override, to enclosure
super.storeinscheduleMicrotaskto make surestorewon't precedeob.updateMethod.override -
toString(
) → String -
A string representation of this object.
inherited
-
touch(
) → void -
Activate automatic aspect management for this watched variable.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited